@@ -27,7 +27,7 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
                                          QIcon(":/images/button-password.png")));
     this->setWindowFlags(Qt::Dialog);
     this->setWindowModality(Qt::ApplicationModal);
-    this->setMinimumSize(640, 480);
+    this->setMinimumSize(640, 520);
 
     this->pController = pumpController;
 
@@ -72,14 +72,16 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
                                                 QIcon(":/images/no-avatar.png"))
                                .pixmap(64,64)
                                .scaledToWidth(64, Qt::SmoothTransformation));
-    userIDLabel = new QLabel(tr("Your Pump.io address:"), this);
-    userIDLineEdit = new QLineEdit(this);
+    userIdLabel = new QLabel("<b>" + tr("Your Pump.io address:") + "</b>",
+                             this);
+    userIdLineEdit = new QLineEdit(this);
     QString userIdTooltip = tr("Your address, like username@pumpserver.org");
-    userIDLineEdit->setPlaceholderText(userIdTooltip);
-    userIDLineEdit->setToolTip("<b></b>" + userIdTooltip); // HTMLized for wordwrap
+    userIdLineEdit->setPlaceholderText(userIdTooltip);
+    userIdLineEdit->setToolTip("<b></b>" + userIdTooltip); // HTMLized for wordwrap
 
     getVerifierButton = new QPushButton(QIcon::fromTheme("object-unlocked"),
-                                        tr("Get &Verifier Code"), this);
+                                        tr("Get &Verifier Code"),
+                                        this);
     getVerifierButton->setToolTip("<b></b>" +
                                   tr("After clicking this button, a web "
                                      "browser will open, requesting "
@@ -87,6 +89,9 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     connect(getVerifierButton, SIGNAL(clicked()),
             this, SLOT(askForToken()));
 
+    this->separatorLine = new QFrame(this);
+    separatorLine->setFrameStyle(QFrame::HLine);
+
 
     this->helpMessage2Label = new QLabel(tr("Once you have authorized Dianara "
                                             "from your Pump server web "
@@ -106,7 +111,8 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
                                                   QIcon(":/images/button-password.png"))
                                  .pixmap(64,64)
                                  .scaledToWidth(64, Qt::SmoothTransformation));
-    verifierLabel = new QLabel(tr("Verifier code:"), this);
+    verifierLabel = new QLabel("<b>" + tr("Verifier code:") + "</b>",
+                               this);
     verifierLineEdit = new QLineEdit(this);
     QString verifierTooltip = tr("Enter or paste the verifier code provided "
                                  "by your Pump server here");
@@ -126,7 +132,7 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     // Cleared when typing in any of the two fields
     errorsLabel = new QLabel(this);
     errorsLabel->setOpenExternalLinks(true);
-    connect(userIDLineEdit, SIGNAL(textChanged(QString)),
+    connect(userIdLineEdit, SIGNAL(textChanged(QString)),
             errorsLabel, SLOT(clear()));
     connect(verifierLineEdit, SIGNAL(textChanged(QString)),
             errorsLabel, SLOT(clear()));
@@ -170,7 +176,8 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     unlockExplanationLabel->setAlignment(Qt::AlignHCenter);
 
     this->unlockButton = new QPushButton(QIcon::fromTheme("object-unlocked"),
-                                         tr("&Unlock"), this);
+                                         tr("&Unlock"),
+                                         this);
     connect(unlockButton, SIGNAL(clicked()),
             this, SLOT(unlockDialog()));
 
@@ -179,8 +186,8 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     this->idLayout = new QHBoxLayout();
     idLayout->addWidget(userIDIconLabel);
     idLayout->addSpacing(4);
-    idLayout->addWidget(userIDLabel);
-    idLayout->addWidget(userIDLineEdit);
+    idLayout->addWidget(userIdLabel);
+    idLayout->addWidget(userIdLineEdit);
     idLayout->addWidget(getVerifierButton);
 
     this->verifierLayout = new QHBoxLayout();
@@ -205,6 +212,9 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     mainLayout->addSpacing(8);
     mainLayout->addStretch(1);
     mainLayout->addLayout(idLayout, 2);
+    mainLayout->addSpacing(16);
+    mainLayout->addStretch(1);
+    mainLayout->addWidget(separatorLine);
     mainLayout->addStretch(1);
     mainLayout->addSpacing(16);
     mainLayout->addWidget(helpMessage2Label, 2);
@@ -212,16 +222,16 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     mainLayout->addStretch(1);
     mainLayout->addLayout(verifierLayout, 2);
     mainLayout->addWidget(errorsLabel,              1, Qt::AlignCenter);
-    mainLayout->addSpacing(4);
+    mainLayout->addSpacing(2);
     mainLayout->addWidget(authorizationStatusLabel, 1, Qt::AlignCenter);
-    mainLayout->addStretch(1);
-    mainLayout->addSpacing(8);
+    mainLayout->addStretch(2);
+    mainLayout->addSpacing(20);
     mainLayout->addLayout(buttonsLayout, 1);
     this->setLayout(mainLayout);
 
 
     QSettings settings;  // Load saved User ID
-    userIDLineEdit->setText(settings.value("userID").toString());
+    userIdLineEdit->setText(settings.value("userID").toString());
 
     this->showAuthorizationStatus(settings.value("isApplicationAuthorized",
                                                  false).toBool());
@@ -248,6 +258,7 @@ void AccountDialog::setLockMode(bool locked)
     if (locked)
     {
         this->helpMessage1Label->hide();
+        this->separatorLine->hide();
         this->helpMessage2Label->hide();
 
         this->unlockExplanationLabel->show();
@@ -259,13 +270,14 @@ void AccountDialog::setLockMode(bool locked)
     else
     {
         this->helpMessage1Label->show();
+        this->separatorLine->show();
         this->helpMessage2Label->show();
 
         this->unlockExplanationLabel->hide();
         this->unlockButton->hide();
     }
 
-    this->userIDLineEdit->setDisabled(locked);
+    this->userIdLineEdit->setDisabled(locked);
     this->getVerifierButton->setDisabled(locked);
 }
 
@@ -283,11 +295,11 @@ void AccountDialog::askForToken()
     settings.setValue("isApplicationAuthorized", false); // Until steps are completed
 
     // Don't fail if there're spaces before or after the ID, they're only human ;)
-    userIDLineEdit->setText(userIDLineEdit->text().trimmed());
+    userIdLineEdit->setText(userIdLineEdit->text().trimmed());
 
     // Match username@server.tld AND check for only 1 @ sign
-    if (QRegExp("\\S+@\\S+\\.\\S+").exactMatch(this->userIDLineEdit->text())
-     && userIDLineEdit->text().count("@") == 1)
+    if (QRegExp("\\S+@\\S+\\.\\S+").exactMatch(this->userIdLineEdit->text())
+     && userIdLineEdit->text().count("@") == 1)
     {
         // Clear verifier field and re-enable it and the button
         this->verifierLineEdit->clear();
@@ -301,7 +313,7 @@ void AccountDialog::askForToken()
                                         "where you can get the verifier code")
                                    + " ]");
 
-        this->pController->setNewUserId(userIDLineEdit->text());
+        this->pController->setNewUserId(userIdLineEdit->text());
         this->pController->getToken();
     }
     else // userID does not match user@hostname.domain
@@ -376,17 +388,17 @@ void AccountDialog::showAuthorizationURL(QUrl url)
  */
 void AccountDialog::saveDetails()
 {
-    QString newUserID = this->userIDLineEdit->text().trimmed();
-    if (newUserID.isEmpty() || !newUserID.contains("@"))
+    QString newUserId = this->userIdLineEdit->text().trimmed();
+    if (newUserId.isEmpty() || !newUserId.contains("@"))
     {
         return;  // If no user ID, or with no "@", ignore // FIXME
     }
 
     QSettings settings;
-    settings.setValue("userID", newUserID);
+    settings.setValue("userID", newUserId);
     settings.sync();
 
-    emit userIDChanged(newUserID);
+    emit userIDChanged(newUserId);
 
 
     this->errorsLabel->clear(); // Clear previous error messages, if any
