@@ -31,9 +31,12 @@ AvatarButton::AvatarButton(ASPerson *person,
     this->globalObj = globalObject;
 
     this->setPopupMode(QToolButton::InstantPopup);
-    this->setStyleSheet("QToolButton { border: none }"
-                        "QToolButton:hover { border: none; "
-                        "                    background-color: palette(highlight) }");
+    this->setStyleSheet("QToolButton { border: none;       "
+                        "              border-radius: 8px; "
+                        "              padding: 2px       }"
+                        "QToolButton:hover { border: none;          "
+                        "                    background-color:      "
+                        "                       palette(highlight) }");
     this->setIconSize(avatarSize);
     this->setMinimumSize(avatarSize);
     this->iconWidth = avatarSize.width();
@@ -62,6 +65,7 @@ AvatarButton::AvatarButton(ASPerson *person,
     this->authorName = person->getNameWithFallback();
     this->authorUrl = person->getUrl();
     this->authorAvatarUrl = person->getAvatar();
+    this->authorOutbox = person->getOutboxLink();
 
     this->authorFollowed = false; // Real status will be read when creating the menu
 
@@ -165,13 +169,27 @@ void AvatarButton::createAvatarMenu()
             this, SLOT(sendMessageToUser()));
 
 
-    // Only add "follow/unfollow" and "send message" options if we're not the author
-    if (!userIsAuthor)
+    this->avatarMenuBrowseAction = new QAction(QIcon::fromTheme("edit-find",
+                                                                QIcon(":/images/menu-find.png")),
+                                               tr("Browse messages"),
+                                               this);
+    connect(avatarMenuBrowseAction, SIGNAL(triggered()),
+            this, SLOT(browseUserMessages()));
+
+    // Disable 'browse' option if not available (empty or in another server)
+    if (!pController->urlIsInOurHost(this->authorOutbox))
+    {
+        this->avatarMenuBrowseAction->setDisabled(true);
+    }
+
+
+    // Only add "follow/unfollow", "send message" and "browse messages"
+    if (!userIsAuthor)  // options if we're not the author
     {
         avatarMenu->addAction(avatarMenuFollowAction);
         this->syncFollowState(true);
-
         avatarMenu->addAction(avatarMenuMessageAction);
+        avatarMenu->addAction(avatarMenuBrowseAction);
     }
 
     //
@@ -262,9 +280,11 @@ void AvatarButton::followUser()
 void AvatarButton::unfollowUser()
 {
     int confirmation = QMessageBox::question(this, tr("Stop following?"),
-                                             tr("Are you sure you want to stop following %1?")
+                                             tr("Are you sure you want to "
+                                                "stop following %1?")
                                              .arg(this->authorId),
-                                             tr("&Yes, stop following"), tr("&No"), "", 1, 1);
+                                             tr("&Yes, stop following"),
+                                             tr("&No"), "", 1, 1);
 
     if (confirmation == 0)
     {
@@ -282,6 +302,14 @@ void AvatarButton::sendMessageToUser()
 
 }
 
+void AvatarButton::browseUserMessages()
+{
+    this->globalObj->browseUserMessages(this->authorId,
+                                        this->authorName,
+                                        this->icon(),
+                                        this->authorOutbox + "/major");
+}
+
 
 
 /*
