@@ -516,6 +516,8 @@ void Comment::quoteComment()
     else
     {
         // Quote the selection only
+        commentSelectedText.prepend("[...] ");
+        commentSelectedText.append(" [...]");
         quotedComment = MiscHelpers::quotedText(this->fullNameLabel->text(),
                                                 this->commentSelectedText);
     }
