@@ -35,7 +35,9 @@ CommenterBlock::CommenterBlock(PumpController *pumpController,
     this->currentCommentCount = 0;
     this->allCommentsShown = false;
 
-    this->reloadCommentsString = tr("Reload comments");
+    this->reloadCommentsString = QString::fromUtf8("\342\206\273") // Reload symbol
+                                 + " &nbsp;"
+                                 + tr("Reload comments");
     this->showAllCommentsLinkLabel = new QLabel("<a href=\"showall://\">"
                                                 + reloadCommentsString
                                                 + "</a>",
@@ -381,6 +383,7 @@ void CommenterBlock::adjustCommentsHeight()
     if (this->commentsScrollArea->isVisible())
     {
         this->commentsScrollArea->hide();
+        // this->commentsWidget->ensurePolished(); // Disabled for 1.3.1; using classic resize stuff
         this->commentsScrollArea->show();
     }
 }
