@@ -156,12 +156,21 @@ Composer::Composer(GlobalObject *globalObject, bool forPublisher)
     nickCompleter = new QCompleter(globalObj->getNickCompletionModel(),
                                    this);
     nickCompleter->setWidget(this);
-    nickCompleter->setMaxVisibleItems(10);
+    nickCompleter->setMaxVisibleItems(15);
+    nickCompleter->setCompletionColumn(0);
     nickCompleter->setCaseSensitivity(Qt::CaseInsensitive);
     nickCompleter->setModelSorting(QCompleter::CaseSensitivelySortedModel); // TMP; FIXME
     connect(nickCompleter, SIGNAL(activated(QModelIndex)),
             this, SLOT(insertCompletedNick(QModelIndex)));
 
+    popupTableView = new QTableView(this);
+    popupTableView->horizontalHeader()->hide();
+    popupTableView->verticalHeader()->hide();
+    popupTableView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    popupTableView->setAlternatingRowColors(true);
+    popupTableView->setSelectionBehavior(QAbstractItemView::SelectRows);
+    nickCompleter->setPopup(popupTableView);
+
     mainLayout = new QHBoxLayout();
 
     if (this->forPublisher)  // Publisher mode
@@ -228,10 +237,30 @@ void Composer::insertLink(QString url, QString title)
 void Composer::requestCompletion(QString partialNick)
 {
     nickCompleter->setCompletionPrefix(partialNick);
+    popupTableView->ensurePolished();
+
+    popupTableView->resizeColumnsToContents();
+    popupTableView->resizeRowsToContents();
+    popupTableView->ensurePolished();
+
+    int tableWidth = popupTableView->columnWidth(0)
+                     + popupTableView->columnWidth(1) + 2;
+    if (tableWidth > this->width() + 2)
+    {
+        tableWidth = this->width() + 2;
+        popupTableView->setColumnWidth(0, (tableWidth / 4) * 3);
+        popupTableView->setColumnWidth(1, tableWidth / 4);
+    }
+
+    popupTableView->setMinimumWidth(tableWidth);
+
+    int rows = qMin(popupTableView->model()->rowCount(), 15);
+    int rowHeight = popupTableView->rowHeight(0) + 4;
+    popupTableView->setMinimumHeight(rows * rowHeight);
 
     nickCompleter->complete(QRect(this->cursorRect().x(),
-                                  this->cursorRect().y(),
-                                  256, 1));
+                                  this->cursorRect().y() + 24,
+                                  tableWidth, 1));
 }
 
 
@@ -396,41 +425,84 @@ void Composer::contextMenuEvent(QContextMenuEvent *event)
  */
 void Composer::insertFromMimeData(const QMimeData *source)
 {
-    QString pastedText = source->text().trimmed();
-
-    if (pastedText.startsWith("http://")
-     || pastedText.startsWith("https://"))
+    if (source->hasHtml())
     {
-        int insertionType = 1;
+        // It's rich text, so just paste it as is
+        QTextEdit::insertFromMimeData(source);
+    }
+    else
+    {
+        QString pastedText = source->text().trimmed();
 
-        // If link looks like an image, ask the user how to insert it
-        if (pastedText.endsWith(".png", Qt::CaseInsensitive)
-         || pastedText.endsWith(".jpg", Qt::CaseInsensitive)
-         || pastedText.endsWith(".jpeg", Qt::CaseInsensitive)
-         || pastedText.endsWith(".gif", Qt::CaseInsensitive))
+        if (pastedText.startsWith("http://")
+         || pastedText.startsWith("https://"))
         {
-            insertionType = QMessageBox::question(this,
-                                         tr("Insert as image?"),
-                                         tr("The link you are pasting seems to "
-                                            "point to an image.") + "\n",
-                                         tr("Insert as visible image"), // Default option (enter)
-                                         tr("Insert as link"),  // ESC option
-                                         "", 0, 1);
-        }
+            int insertionType = 1;
 
-        if (insertionType == 0) // Default button, insert as image
-        {
-            this->insertHtml("<img src=\"" + pastedText + "\" />");
+            // If link looks like an image, ask the user how to insert it
+            if (pastedText.endsWith(".png", Qt::CaseInsensitive)
+             || pastedText.endsWith(".jpg", Qt::CaseInsensitive)
+             || pastedText.endsWith(".jpeg", Qt::CaseInsensitive)
+             || pastedText.endsWith(".gif", Qt::CaseInsensitive))
+            {
+                insertionType = QMessageBox::question(this,
+                                             tr("Insert as image?"),
+                                             tr("The link you are pasting seems to "
+                                                "point to an image.") + "\n",
+                                             tr("Insert as visible image"), // Default option (enter)
+                                             tr("Insert as link"),  // ESC option
+                                             "", 0, 1);
+            }
+
+            if (insertionType == 0) // Default button, insert as image
+            {
+                this->insertHtml("<img src=\"" + pastedText + "\" />");
+            }
+            else
+            {
+                this->insertLink(pastedText);
+            }
         }
         else
         {
-            this->insertLink(pastedText);
+            if (pastedText.contains("://")) // Probably contains links
+            {
+                qDebug() << "Looking for URL's to htmlize";
+
+                QRegExp regExp("(http|https|ftp)://(.*)(\\s|$)");
+                regExp.setMinimal(true);
+
+                QString link;
+                int matchedLength = 0;
+                int stringPos = 0;
+                while (matchedLength != -1)
+                {
+                    stringPos = regExp.indexIn(pastedText, stringPos);
+                    matchedLength = regExp.matchedLength();
+
+                    qDebug() << regExp.capturedTexts();
+                    link = regExp.cap(0);
+                    QString htmlLink;
+                    if (!link.isEmpty()) // if not an empty string, replace HTML
+                    {
+                        htmlLink = "<a href=\"" + link +  "\">" + link + "</a>";
+                        pastedText.replace(stringPos, matchedLength, htmlLink);
+                    }
+
+                    stringPos += htmlLink.length();
+                }
+
+                pastedText.replace("\n", "<br>");
+
+                this->insertHtml(pastedText + "&nbsp;");
+            }
+            else  // Just paste original contents
+            {
+                qDebug() << "direct paste";
+                QTextEdit::insertFromMimeData(source);
+            }
         }
     }
-    else // Just paste original contents
-    {
-        QTextEdit::insertFromMimeData(source);
-    }
 }
 
 
@@ -621,7 +693,9 @@ void Composer::makeQuote()
     {
         this->textCursor().removeSelectedText();
         this->insertHtml("<br />"
-                         "<blockquote>&ldquo;" + selectedText + "&rdquo;</blockquote><br>");
+                         "<blockquote>&ldquo;" + selectedText
+                         + "&rdquo;</blockquote>"
+                           "<br />");
     }
     // FIXME: Qt's HTML changes <blockquote> into its own formatting
     // so other clients and the web UI might not display it as other people's blockquote's
@@ -655,11 +729,13 @@ void Composer::makeLink()
     }
     else
     {
+        QString shortenedText = MiscHelpers::elidedText(selectedText, 40);
+
         link = QInputDialog::getText(this,
                                      tr("Make a link from selected text"),
                                      tr("Type or paste a web address here.\n"
                                         "The selected text (%1) will be converted "
-                                        "to a link.").arg(selectedText)
+                                        "to a link.").arg(shortenedText)
                                      + "\n\n",
                                      QLineEdit::Normal,
                                      "http://");
@@ -819,6 +895,4 @@ void Composer::cancelPost()
 
         qDebug() << "Post canceled";
     }
-
-
 }
