@@ -35,10 +35,13 @@
 #include <QCompleter>
 #include <QAbstractItemView> // For QCompleter's popup
 #include <QStandardItemModel>
+#include <QTableView>
+#include <QHeaderView>
 
 #include <QDebug>
 
 #include "globalobject.h"
+#include "mischelpers.h"
 
 
 class Composer : public QTextEdit
@@ -113,6 +116,7 @@ private:
     QMenu *customContextMenu;
 
     QCompleter *nickCompleter;
+    QTableView *popupTableView;
 
     bool forPublisher;
 
