@@ -242,15 +242,21 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
 
     showDeletedCheckbox = new QCheckBox(this);
     showDeletedCheckbox->setChecked(globalObj->getShowDeleted());
-    //timelinesOptionsLayout->addRow("Show frame of deleted posts", // Not translatable for now
-    //                               showDeletedCheckbox);
-    showDeletedCheckbox->hide(); // Hidden option for now (FIXME v1.3.1)
+    /*
+    timelinesOptionsLayout->addRow("Show frame of deleted posts", // Not translatable for now
+                                   showDeletedCheckbox);          // FIXME 1.3.2
+    */
+    showDeletedCheckbox->hide(); // TMP, FIXME 1.3.2
 
     hideDuplicatesCheckbox = new QCheckBox(this);
     hideDuplicatesCheckbox->setChecked(globalObj->getHideDuplicates());
     timelinesOptionsLayout->addRow(tr("Hide duplicated posts"),
                                    hideDuplicatesCheckbox);
 
+    jumpToNewCheckbox = new QCheckBox(this);
+    jumpToNewCheckbox->setChecked(globalObj->getJumpToNewOnUpdate());
+    timelinesOptionsLayout->addRow(tr("Jump to new posts line on update"),
+                                   jumpToNewCheckbox);
 
     timelinesOptionsWidget = new QWidget(this);
     timelinesOptionsWidget->setLayout(timelinesOptionsLayout);
@@ -328,7 +334,24 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
 
 
 
-    // Page 7, notifications options
+    // Page 7, privacy options
+    silentFollowsCheckbox = new QCheckBox(this);
+    silentFollowsCheckbox->setChecked(globalObj->getSilentFollows());
+    silentListsCheckbox = new QCheckBox(this);
+    silentListsCheckbox->setChecked(globalObj->getSilentLists());
+
+    privacyOptionsLayout = new QFormLayout();
+    privacyOptionsLayout->addRow(tr("Don't inform followers when following someone"),
+                                 silentFollowsCheckbox);
+    privacyOptionsLayout->addRow(tr("Don't inform followers when handling lists"),
+                                 silentListsCheckbox);
+
+    privacyOptionsWidget = new QWidget(this);
+    privacyOptionsWidget->setLayout(privacyOptionsLayout);
+
+
+
+    // Page 8, notifications options
     notificationOptionsLayout = new QFormLayout();
 
     notificationStyleCombobox = new QComboBox(this);
@@ -386,7 +409,7 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
 
 
 
-    // Page 8, systray options
+    // Page 9, systray options
     systrayOptionsLayout = new QFormLayout();
 
     systrayIconTypeCombobox = new QComboBox(this);
@@ -419,6 +442,11 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     systrayOptionsLayout->addRow(tr("Custom &Icon"),
                                  systrayCustomIconButton);
 
+    systrayHideCheckbox = new QCheckBox(this);
+    systrayHideCheckbox->setChecked(globalObject->getHideInTray());
+    systrayOptionsLayout->addRow(tr("Hide window on startup"),
+                                 systrayHideCheckbox);
+
     systrayOptionsWidget = new QWidget(this);
     systrayOptionsWidget->setLayout(systrayOptionsLayout);
 
@@ -427,7 +455,7 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
 
 
     ///////////////////////////////////// List of categories and stacked widget
-    categoriesListWidget = new QListWidget();
+    categoriesListWidget = new QListWidget(this);
     categoriesListWidget->setSizePolicy(QSizePolicy::Preferred,
                                         QSizePolicy::MinimumExpanding);
     categoriesListWidget->setMinimumWidth(100); // kinda TMP/FIXME
@@ -461,14 +489,17 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     categoriesListWidget->addItem(tr("Composer"));
     categoriesListWidget->item(5)->setIcon(QIcon::fromTheme("document-edit",
                                                             QIcon(":/images/button-edit.png")));
+    categoriesListWidget->addItem(tr("Privacy"));
+    categoriesListWidget->item(6)->setIcon(QIcon::fromTheme("object-locked",
+                                                            QIcon(":/images/button-password.png")));
     categoriesListWidget->addItem(tr("Notifications"));
-    categoriesListWidget->item(6)->setIcon(QIcon::fromTheme("preferences-desktop-notification",
+    categoriesListWidget->item(7)->setIcon(QIcon::fromTheme("preferences-desktop-notification",
                                                             QIcon(":/images/button-online.png")));
     categoriesListWidget->addItem(tr("System Tray"));     // dashboard-show ?
-    categoriesListWidget->item(7)->setIcon(QIcon::fromTheme("configure-toolbars",
+    categoriesListWidget->item(8)->setIcon(QIcon::fromTheme("configure-toolbars",
                                                             QIcon(":/images/button-configure.png")));
 
-    categoriesStackedWidget = new QStackedWidget();
+    categoriesStackedWidget = new QStackedWidget(this);
     categoriesStackedWidget->setSizePolicy(QSizePolicy::Preferred,
                                            QSizePolicy::MinimumExpanding);
     categoriesStackedWidget->addWidget(generalOptionsWidget);
@@ -477,6 +508,7 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     categoriesStackedWidget->addWidget(timelinesOptionsWidget);
     categoriesStackedWidget->addWidget(postsOptionsWidget);
     categoriesStackedWidget->addWidget(composerOptionsWidget);
+    categoriesStackedWidget->addWidget(privacyOptionsWidget);
     categoriesStackedWidget->addWidget(notificationOptionsWidget);
     categoriesStackedWidget->addWidget(systrayOptionsWidget);
 
@@ -494,7 +526,8 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     // Label to show where the data directory is
     dataDirectoryLabel = new QLabel(tr("Dianara stores data in this folder:")
                                     + QString(" <a href=\"%1\">%2</a>")
-                                      .arg(dataDirectory).arg(dataDirectory));
+                                      .arg(dataDirectory).arg(dataDirectory),
+                                    this);
     dataDirectoryLabel->setWordWrap(true);
     dataDirectoryLabel->setOpenExternalLinks(true);
 
@@ -502,12 +535,14 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     // Save / Cancel buttons
     saveConfigButton = new QPushButton(QIcon::fromTheme("document-save",
                                                         QIcon(":/images/button-save.png")),
-                                 tr("&Save Configuration"));
+                                       tr("&Save Configuration"),
+                                       this);
     connect(saveConfigButton, SIGNAL(clicked()),
             this, SLOT(saveConfiguration()));
     cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
                                                     QIcon(":/images/button-cancel.png")),
-                                   tr("&Cancel"));
+                                   tr("&Cancel"),
+                                   this);
     connect(cancelButton, SIGNAL(clicked()),
             this, SLOT(hide()));
 
@@ -539,6 +574,7 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
 
     // Activate the first category (so the row already looks selected)
     this->categoriesListWidget->setCurrentRow(0);
+    this->categoriesListWidget->setFocus();
 
     qDebug() << "Config dialog created";
 }
@@ -665,13 +701,16 @@ void ConfigDialog::saveConfiguration()
                       this->showDeletedCheckbox->isChecked());
     settings.setValue("hideDuplicatedPosts",
                       this->hideDuplicatesCheckbox->isChecked());
+    settings.setValue("jumpToNewOnUpdate",
+                      this->jumpToNewCheckbox->isChecked());
 
     this->globalObj->syncTimelinesSettings(this->postsPerPageMainSpinbox->value(),
                                            this->postsPerPageOtherSpinbox->value(),
                                            this->minorFeedSnippetsCombobox->currentIndex(),
                                            this->snippetLimitSpinbox->value(),
                                            this->showDeletedCheckbox->isChecked(),
-                                           this->hideDuplicatesCheckbox->isChecked());
+                                           this->hideDuplicatesCheckbox->isChecked(),
+                                           this->jumpToNewCheckbox->isChecked());
 
     // Posts
     settings.setValue("postAvatarSizeIndex",
@@ -706,6 +745,15 @@ void ConfigDialog::saveConfiguration()
                                           this->showCharacterCounterCheckbox->isChecked());
 
 
+    // Privacy
+    settings.setValue("silentFollows",
+                      this->silentFollowsCheckbox->isChecked());
+    settings.setValue("silentLists",
+                      this->silentListsCheckbox->isChecked());
+    this->globalObj->syncPrivacySettings(this->silentFollowsCheckbox->isChecked(),
+                                         this->silentListsCheckbox->isChecked());
+
+
     // Notifications
     settings.setValue("showNotifications",
                       this->notificationStyleCombobox->currentIndex());
@@ -720,7 +768,8 @@ void ConfigDialog::saveConfiguration()
     // Tray
     settings.setValue("systrayIconType", this->systrayIconTypeCombobox->currentIndex());
     settings.setValue("systrayCustomIconFN", this->systrayCustomIconFN);
-    this->globalObj->syncTrayOptions(); // FIXME, still empty
+    settings.setValue("systrayHideInTray", this->systrayHideCheckbox->isChecked());
+    this->globalObj->syncTrayOptions(this->systrayHideCheckbox->isChecked()); // FIXME, some still empty
 
 
     settings.endGroup();
