@@ -97,7 +97,6 @@ private:
     QFormLayout *generalOptionsLayout;
 
     QSpinBox *updateIntervalSpinbox;
-    QCheckBox *publicPostsCheckbox;
     QComboBox *tabsPositionCombobox;
     QCheckBox *tabsMovableCheckbox;
 
@@ -142,6 +141,8 @@ private:
     QCheckBox *showDeletedCheckbox;
     QCheckBox *hideDuplicatesCheckbox;
 
+    QCheckBox *jumpToNewCheckbox;
+
 
     // Page 5, posts options
     QWidget *postsOptionsWidget;
@@ -160,11 +161,22 @@ private:
     QWidget *composerOptionsWidget;
     QFormLayout *composerOptionsLayout;
 
+    QCheckBox *publicPostsCheckbox;
     QCheckBox *useFilenameAsTitleCheckbox;
     QCheckBox *showCharacterCounterCheckbox;
 
 
-    // Page 7, notifications options
+
+    // Page 7, privacy options
+    QWidget *privacyOptionsWidget;
+    QFormLayout *privacyOptionsLayout;
+
+    QCheckBox *silentFollowsCheckbox;
+    QCheckBox *silentListsCheckbox;
+
+
+
+    // Page 8, notifications options
     QWidget *notificationOptionsWidget;
     QFormLayout *notificationOptionsLayout;
 
@@ -176,7 +188,7 @@ private:
     QCheckBox *notifyHLMWCheckbox;
 
 
-    // Page 8, system tray options
+    // Page 9, system tray options
     QWidget *systrayOptionsWidget;
     QFormLayout *systrayOptionsLayout;
 
@@ -184,6 +196,7 @@ private:
     QPushButton *systrayCustomIconButton;
     QString systrayCustomIconFN;
     QString systrayIconLastUsedDir;
+    QCheckBox *systrayHideCheckbox;
 
 
     // Widgets below the tab widget
