@@ -64,6 +64,8 @@ ContactCard::ContactCard(PumpController *pumpController,
     this->contactName = asPerson->getName();
     this->contactId = asPerson->getId();
     this->contactUrl = asPerson->getUrl();
+    this->contactOutbox = asPerson->getOutboxLink();
+
 
     QString userInfoString = QString("<b><u>%1</u></b><br>").arg(contactName);
     userInfoString.append(QString("%1<br>").arg(contactId));
@@ -152,6 +154,14 @@ ContactCard::ContactCard(PumpController *pumpController,
     connect(sendMessageAction, SIGNAL(triggered()),
             this, SLOT(setMessagingModeForContact()));
 
+    browsePostsAction = new QAction(QIcon::fromTheme("edit-find",
+                                                     QIcon(":/images/menu-find.png")),
+                                    tr("Browse Messages"),
+                                    this);
+    connect(browsePostsAction, SIGNAL(triggered()),
+            this, SLOT(browseContactPosts()));
+
+
     addToListMenu = new QMenu(tr("In Lists..."), this);
     addToListMenu->setIcon(QIcon::fromTheme("format-list-unordered"));
     addToListMenu->addAction("fake list 1")->setCheckable(true); // FIXME...
@@ -162,7 +172,9 @@ ContactCard::ContactCard(PumpController *pumpController,
     optionsMenu = new QMenu("*options*", this);
     optionsMenu->addAction(openProfileAction);
     optionsMenu->addAction(sendMessageAction);
-    //optionsMenu->addMenu(addToListMenu); // Don't include it for now, until 1.3 /FIXME
+    optionsMenu->addAction(browsePostsAction);
+    browsePostsAction->setEnabled(pController->urlIsInOurHost(this->contactOutbox));
+    //optionsMenu->addMenu(addToListMenu); // Don't include it for now, until 1.4 /FIXME
 
 
     optionsButton = new QPushButton(QIcon::fromTheme("user-properties",
@@ -181,7 +193,7 @@ ContactCard::ContactCard(PumpController *pumpController,
 
     mainLayout = new QHBoxLayout();
     mainLayout->addWidget(avatarLabel,   0, Qt::AlignTop);
-    mainLayout->addWidget(userInfoLabel, 1, Qt::AlignLeft);
+    mainLayout->addWidget(userInfoLabel, 1);
     mainLayout->addLayout(rightLayout);
     this->setLayout(mainLayout);
 
@@ -298,6 +310,16 @@ void ContactCard::setMessagingModeForContact()
                                              this->contactUrl);
 }
 
+void ContactCard::browseContactPosts()
+{
+    const QPixmap contactPixmap(this->avatarLabel->pixmap()->copy());
+
+    this->globalObj->browseUserMessages(this->contactId,
+                                        this->contactName,
+                                        QIcon(contactPixmap),
+                                        this->contactOutbox + "/major"); // TMP!
+}
+
 
 
 /*
