@@ -37,6 +37,15 @@ ContactList::ContactList(PumpController *pumpController,
     connect(filterLineEdit, SIGNAL(textChanged(QString)),
             this, SLOT(filterList(QString)));
 
+
+    int iconSize = this->filterLineEdit->sizeHint().height(); // filterLineEdit->font().pixelSize()?
+    this->filterIcon = new QLabel(this);
+    filterIcon->setAlignment(Qt::AlignCenter);
+    filterIcon->setPixmap(QIcon::fromTheme("edit-find",
+                                           QIcon(":/images/menu-find.png"))
+                          .pixmap(iconSize, iconSize));
+
+
     this->removeFilterButton = new QPushButton(QIcon::fromTheme("view-list-icons"),
                                                tr("F&ull List"),
                                                this);
@@ -54,6 +63,7 @@ ContactList::ContactList(PumpController *pumpController,
 
     // Layout
     this->filterLayout = new QHBoxLayout();
+    filterLayout->addWidget(filterIcon, 0, Qt::AlignVCenter);
     filterLayout->addWidget(filterLineEdit);
     filterLayout->addWidget(removeFilterButton);
 
@@ -257,6 +267,8 @@ void ContactList::addSingleContact(ASPerson *contact)
         this->globalObj->addToNickCompletionModel(contact->getId(),
                                                   contact->getNameWithFallback(),
                                                   contact->getUrl());
+
+        this->globalObj->sortNickCompletionModel();
     }
 }
 
