@@ -25,6 +25,8 @@ ContactManager::ContactManager(PumpController *pumpController,
                                QWidget *parent) : QWidget(parent)
 {
     this->pController = pumpController;
+    this->globalObj = globalObject;
+
     // After receiving a contact list, update it
     connect(pController, SIGNAL(contactListReceived(QString,QVariantList,int)),
             this, SLOT(setContactListsContents(QString,QVariantList,int)));
@@ -42,13 +44,13 @@ ContactManager::ContactManager(PumpController *pumpController,
     QString webfingerHelpMessage = tr("username@server.org or https://server.org/username");
 
     topLayout = new QHBoxLayout();
-    enterAddressLabel = new QLabel(tr("&Enter address to follow:"));
+    enterAddressLabel = new QLabel(tr("&Enter address to follow:"), this);
     enterAddressLabel->setToolTip("<b></b>"
                                   + webfingerHelpMessage); // HTML tags for wordwrap
     // Ensure it will get focus first, before addressLineEdit
     enterAddressLabel->setFocusPolicy(Qt::StrongFocus);
 
-    addressLineEdit = new QLineEdit();
+    addressLineEdit = new QLineEdit(this);
     addressLineEdit->setPlaceholderText(webfingerHelpMessage);
     addressLineEdit->setToolTip("<b></b>"
                                 + webfingerHelpMessage);  // HTML tags to get wordwrap
@@ -62,7 +64,8 @@ ContactManager::ContactManager(PumpController *pumpController,
 
     followButton = new QPushButton(QIcon::fromTheme("list-add-user",
                                                     QIcon(":/images/list-add.png")),
-                                   tr("&Follow"));
+                                   tr("&Follow"),
+                                   this);
     followButton->setDisabled(true); // Disabled until an address is typed
     connect(followButton, SIGNAL(clicked()),
             this, SLOT(followContact()));
@@ -76,7 +79,7 @@ ContactManager::ContactManager(PumpController *pumpController,
 
     // Widgets for list of 'following' and 'followers'
     this->followingWidget = new ContactList(this->pController,
-                                            globalObject,
+                                            this->globalObj,
                                             "following", this);
     connect(pController, SIGNAL(contactFollowed(ASPerson*)),
             followingWidget, SLOT(addSingleContact(ASPerson*)));
@@ -88,13 +91,13 @@ ContactManager::ContactManager(PumpController *pumpController,
 
 
     this->followersWidget = new ContactList(this->pController,
-                                            globalObject,
+                                            this->globalObj,
                                             "followers", this);
 
 
     // Widget for the list of 'person lists'
     this->listsManager = new ListsManager(this->pController);
-    listsScrollArea = new QScrollArea();
+    listsScrollArea = new QScrollArea(this);
     listsScrollArea->setWidget(this->listsManager);
     listsScrollArea->setWidgetResizable(true);
     listsScrollArea->setFrameStyle(QFrame::NoFrame);
@@ -133,11 +136,11 @@ ContactManager::ContactManager(PumpController *pumpController,
 
     optionsButton = new QPushButton(QIcon::fromTheme("configure",
                                                      QIcon(":/images/button-configure.png")),
-                                    "");
+                                    "", this);
     optionsButton->setMenu(optionsMenu);
 
 
-    this->tabWidget = new QTabWidget();
+    this->tabWidget = new QTabWidget(this);
     tabWidget->addTab(followersWidget,
                       QIcon::fromTheme("meeting-observer",
                                        QIcon(":/images/no-avatar.png")),
@@ -402,11 +405,8 @@ void ContactManager::followContact()
 
     qDebug() << "ContactManager::followContact(); Address entered:" << address;
 
-    if (address.contains(QRegExp(".+@.+")))
-    {
-        validAddress = true;
-    }
-    else if (address.startsWith("https://") || address.startsWith("http://"))
+    // First, if the address is in URL form, convert it
+    if (address.startsWith("https://") || address.startsWith("http://"))
     {
         address.remove("https://");
         address.remove("http://");
@@ -416,23 +416,29 @@ void ContactManager::followContact()
             QStringList addressParts = address.split("/");
             address = addressParts.at(1) + "@" + addressParts.at(0);
             // .at(2) could also have stuff, so don't use .first() and .last()
+        }
+    }
 
-            validAddress = true;
-        }
-        else
-        {
-            qDebug() << "Invalid webfinger address!";
-        }
+    // Then, check that the address actually matches something@somewhere.tld
+    if (address.contains(QRegExp(".+@.+\\..+")))
+    {
+        validAddress = true;
+    }
+    else
+    {
+        qDebug() << "Invalid webfinger address!";
+        this->addressLineEdit->setFocus();
     }
 
 
     if (validAddress)
     {
         qDebug() << "About to follow this address:" << address;
-        this->pController->followContact(address); // this will trigger a reload of the contact list
+        this->pController->followContact(address);
 
         this->addressLineEdit->clear();
         // Activate 'Following' tab
+        this->tabWidget->setFocus();
         this->tabWidget->setCurrentIndex(1);
     }
 
