@@ -75,7 +75,8 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
                                 settings.value("minorFeedSnippets", 0).toInt(),
                                 settings.value("snippetsCharLimit", 200).toInt(),
                                 settings.value("showDeletedPosts", false).toBool(),
-                                settings.value("hideDuplicatedPosts", false).toBool());
+                                settings.value("hideDuplicatedPosts", false).toBool(),
+                                settings.value("jumpToNewOnUpdate", false).toBool());
 
 
     ///////////////////////////////////////////////////////////////////// POSTS
@@ -93,12 +94,18 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
                                settings.value("showCharacterCounter", false).toBool());
 
 
+    /////////////////////////////////////////////////////////////////// PRIVACY
+    this->syncPrivacySettings(settings.value("silentFollows", false).toBool(),
+                              settings.value("silentLists", true).toBool());
+
+
     ///////////////////////////////////////////////////////////// NOTIFICATIONS
     this->syncNotificationSettings(); // Dummy, TODO
 
 
     ////////////////////////////////////////////////////////////////////// TRAY
-    this->syncTrayOptions(); // Dummy, TODO
+    this->syncTrayOptions(settings.value("systrayHideInTray", false).toBool());
+                                          // TODO: load the other tray options
 
 
     settings.endGroup();
@@ -106,6 +113,8 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
 
     // Model for nick completion used by Composer
     this->nickCompletionModel = new QStandardItemModel(this);
+    nickCompletionModel->setColumnCount(2);
+
 
     // Timeline height used to calculate maximum optimal height for post contents
     this->timelineHeight = 400; // Some initial value
@@ -196,7 +205,8 @@ QString GlobalObject::getColor(int colorIndex)
 // Timeline options
 void GlobalObject::syncTimelinesSettings(int pppMain, int pppOther,
                                          int minorFeedSnippets, int snippetsChars,
-                                         bool showDeleted, bool hideDuplicates)
+                                         bool showDeleted, bool hideDuplicates,
+                                         bool jumpToNew)
 {
     this->postsPerPageMain = pppMain;
     this->postsPerPageOther = pppOther;
@@ -207,6 +217,8 @@ void GlobalObject::syncTimelinesSettings(int pppMain, int pppOther,
     this->showDeletedPosts = showDeleted;
     this->hideDuplicatedPosts = hideDuplicates;
 
+    this->jumpToNewOnUpdate = jumpToNew;
+
     // TODO: more...
 }
 
@@ -240,6 +252,11 @@ bool GlobalObject::getHideDuplicates()
     return this->hideDuplicatedPosts;
 }
 
+bool GlobalObject::getJumpToNewOnUpdate()
+{
+    return this->jumpToNewOnUpdate;
+}
+
 
 
 // Post options
@@ -343,6 +360,26 @@ bool GlobalObject::getShowCharacterCounter()
 }
 
 
+
+// Privacy options
+void GlobalObject::syncPrivacySettings(bool silentFollows, bool silentLists)
+{
+    this->silentFollowing = silentFollows;
+    this->silentListsHandling = silentLists;
+}
+
+bool GlobalObject::getSilentFollows()
+{
+    return this->silentFollowing;
+}
+
+bool GlobalObject::getSilentLists()
+{
+    return this->silentListsHandling;
+}
+
+
+
 // Notification options
 void GlobalObject::syncNotificationSettings()
 {
@@ -350,13 +387,20 @@ void GlobalObject::syncNotificationSettings()
 }
 
 
+
 // Tray options
-void GlobalObject::syncTrayOptions()
+void GlobalObject::syncTrayOptions(bool hideInTrayStartup)
 {
-    // TODO, still handled elsewhere
+    this->hideInTray = hideInTrayStartup;
+
+    // TODO, some still handled elsewhere
 }
 
 
+bool GlobalObject::getHideInTray()
+{
+    return this->hideInTray;
+}
 
 ///////////////////////////////////////////////////////////////////////////////
 
@@ -374,6 +418,16 @@ void GlobalObject::createMessageForContact(QString id, QString name,
 
 
 
+void GlobalObject::browseUserMessages(QString userId, QString userName,
+                                      QIcon userAvatar, QString userOutbox)
+{
+    // Signal to be caught by MainWindow
+    emit userTimelineRequested(userId, userName,
+                               userAvatar, userOutbox);
+}
+
+
+
 void GlobalObject::editPost(QString originalPostId,
                             QString type,
                             QString title,
@@ -400,11 +454,17 @@ QStandardItemModel *GlobalObject::getNickCompletionModel()
 void GlobalObject::addToNickCompletionModel(QString id, QString name,
                                             QString url)
 {
-    QStandardItem *item = new QStandardItem(name);
-    item->setData(id,  Qt::UserRole + 1);
-    item->setData(url, Qt::UserRole + 2);
+    QStandardItem *itemName = new QStandardItem(name);
+    itemName->setData(id,  Qt::UserRole + 1);
+    itemName->setData(url, Qt::UserRole + 2);
 
-    this->nickCompletionModel->appendRow(item);
+    QStandardItem *itemId = new QStandardItem(id);
+
+    QList<QStandardItem*> itemLine;
+    itemLine.append(itemName);
+    itemLine.append(itemId);
+
+    this->nickCompletionModel->appendRow(itemLine);
 }
 
 void GlobalObject::removeFromNickCompletionModel(QString id)
