@@ -63,13 +63,15 @@ public:
     // Timeline options
     void syncTimelinesSettings(int pppMain, int pppOther,
                                int minorFeedSnippets, int snippetsChars,
-                               bool showDeleted, bool hideDuplicates);
+                               bool showDeleted, bool hideDuplicates,
+                               bool jumpToNew);
     int getPostsPerPageMain();
     int getPostsPerPageOther();
     int getMinorFeedSnippetsType();
     int getSnippetsCharLimit();
     bool getShowDeleted();
     bool getHideDuplicates();
+    bool getJumpToNewOnUpdate();
 
 
 
@@ -85,6 +87,7 @@ public:
     bool getPostHLOwnComments();
     bool getPostIgnoreSslInImages();
 
+
     // Composer options
     void syncComposerSettings(bool publicPosts, bool filenameAsTitle,
                               bool showCharCounter);
@@ -93,18 +96,29 @@ public:
     bool getShowCharacterCounter();
 
 
+    // Privacy options
+    void syncPrivacySettings(bool silentFollows, bool silentLists);
+    bool getSilentFollows();
+    bool getSilentLists();
+
+
     // Notification options
     void syncNotificationSettings();
 
 
     // Tray options
-    void syncTrayOptions();
+    void syncTrayOptions(bool hideInTrayStartup);
+    bool getHideInTray();
 
 
     ///////////////////////////////////////////////////////////////////////////
 
 
     void createMessageForContact(QString id, QString name, QString url);
+
+    void browseUserMessages(QString userId, QString userName,
+                            QIcon userAvatar, QString userOutbox);
+
     void editPost(QString originalPostId,
                   QString type,
                   QString title,
@@ -125,6 +139,10 @@ public:
 
 signals:
     void messagingModeRequested(QString id, QString name, QString url);
+
+    void userTimelineRequested(QString userId, QString userName,
+                               QIcon userAvatar, QString userOutbox);
+
     void postEditRequested(QString originalPostId,
                            QString type,
                            QString title,
@@ -159,6 +177,7 @@ private:
     int snippetsCharLimit;
     bool showDeletedPosts;
     bool hideDuplicatedPosts;
+    bool jumpToNewOnUpdate;
 
 
     // Post options
@@ -176,11 +195,17 @@ private:
     bool useFilenameAsTitle;
     bool showCharacterCounter;
 
+
+    // Privacy options
+    bool silentFollowing;
+    bool silentListsHandling;
+
+
     // Notification options
 
 
     // Tray options
-
+    bool hideInTray;
 
 
     //////////////////////////////////////////////////////////////////////////
