@@ -31,16 +31,6 @@ ImageViewer::ImageViewer(QString fileURI,
     this->suggestedFilename = suggestedFN;
     this->imageIsAnimated = isAnimated;
 
-    QString tooltipTitle;
-    if (title.isEmpty())
-    {
-        title = "--";
-    }
-    else
-    {
-        tooltipTitle = "<b><u>" + title + "</u></b><br><br>";
-    }
-
     fileURI.remove(0, 7); // remove "image:/" from filename URI
     this->originalFileURI = fileURI;
 
@@ -53,23 +43,23 @@ ImageViewer::ImageViewer(QString fileURI,
                            + MiscHelpers::fileSizeString(originalFileURI);
 
 
+    if (title.isEmpty())
+    {
+        title = "--";
+    }
     this->setWindowTitle(tr("Image") + ": " + title + " - Dianara");
     this->setWindowIcon(QIcon::fromTheme("folder-image",
                                          QIcon(":/images/attached-image.png")));
 
-    imageLabel = new QLabel();
+    imageLabel = new QLabel(this);
     imageLabel->setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
     imageLabel->setAlignment(Qt::AlignCenter);
-    imageLabel->setToolTip(tooltipTitle
-                           + tr("Resolution and file size") + ":<br>"
-                           + imageDetails
-                           + "<br><br>"
-                           + tr("ESC to close, secondary-click for options"));
 
 
     saveImageButton = new QPushButton(QIcon::fromTheme("document-save-as",
                                                        QIcon(":/images/button-save.png")),
-                                      tr("&Save As..."));
+                                      tr("&Save As..."),
+                                      this);
     connect(saveImageButton, SIGNAL(clicked()),
             this, SLOT(saveImage()));
 
@@ -84,17 +74,19 @@ ImageViewer::ImageViewer(QString fileURI,
 
         restartButton = new QPushButton(QIcon::fromTheme("media-playback-start",
                                                          QIcon(":/images/menu-refresh.png")),
-                                        tr("&Restart Animation"));
+                                        tr("&Restart Animation"),
+                                        this);
         connect(restartButton, SIGNAL(clicked()),
                 this, SLOT(restartAnimation()));
     }
 
 
-    infoLabel = new QLabel(imageDetails);
+    infoLabel = new QLabel(imageDetails, this);
     infoLabel->setAlignment(Qt::AlignCenter);
 
     closeButton = new QPushButton(QIcon::fromTheme("window-close"),
-                                  tr("&Close"));
+                                  tr("&Close"),
+                                  this);
     connect(closeButton, SIGNAL(clicked()),
             this, SLOT(close()));
 
