@@ -30,7 +30,7 @@ LogViewer::LogViewer(QWidget *parent) : QWidget(parent)
 
     QSettings settings;
     this->resize(settings.value("LogViewer/logWindowSize",
-                                QSize(600, 400)).toSize());
+                                QSize(760, 560)).toSize());
 
 
     QList<QKeySequence> closeShortcuts;
@@ -129,15 +129,9 @@ void LogViewer::addToLog(QString message, QString url)
 
     if (!url.isEmpty())
     {
-        QString shortenedUrl = url;
-        if (url.length() > 45)
-        {
-            shortenedUrl = url.left(20);
-            shortenedUrl.append(" ... ");
-            shortenedUrl.append(url.right(20));
-        }
-
-        logLine.append(": <a href=\"" + url + "\">" + shortenedUrl + "</a>");
+        logLine.append(": <a href=\"" + url + "\">"
+                       + MiscHelpers::elidedText(url, 40)
+                       + "</a>");
     }
 
     logTextBrowser->append(logLine);
