@@ -38,7 +38,9 @@ void customMessageHandlerQt4(QtMsgType type, const char *msg)
     return;
 }
 #else
-void customMessageHandlerQt5(QtMsgType type, const QMessageLogContext &context, const QString &msg)
+void customMessageHandlerQt5(QtMsgType type,
+                             const QMessageLogContext &context,
+                             const QString &msg)
 {
     Q_UNUSED(type)
     Q_UNUSED(context)
@@ -56,7 +58,7 @@ int main(int argc, char *argv[])
 {
     QApplication dianaraApp(argc, argv);
     dianaraApp.setApplicationName("Dianara");
-    dianaraApp.setApplicationVersion("1.3.0");
+    dianaraApp.setApplicationVersion("1.3.1");
     dianaraApp.setOrganizationName("JanCoding");
     dianaraApp.setOrganizationDomain("jancoding.wordpress.com");
 
@@ -78,7 +80,7 @@ int main(int argc, char *argv[])
 
 
     QStringList cmdLine = qApp->arguments();
-    cmdLine.removeFirst();
+    cmdLine.removeFirst(); // Remove the program executable name/path
 
     bool debugMode = false;
     bool nextParameterIsConfig = false;
@@ -96,15 +98,17 @@ int main(int argc, char *argv[])
                 std::cout << "\nHelp:\n";
                 std::cout << "    " << argv[0] << " [options]\n\n";
                 std::cout << "Options:\n";
-                std::cout << "    -c  --config [name]   Use a different "
+                std::cout << "    -c  --config [name]      Use a different "
                              "configuration file\n";
-                std::cout << "    -d  --debug           Show debug messages "
+                std::cout << "    -d  --debug              Show debug messages "
                              "in the terminal\n";
-                std::cout << "        --ignoresslerrors Ignore SSL errors "
+                std::cout << "        --linkcolor=[color]  Set color for "
+                             "links, such as 'green' or '#00B500'\n";
+                std::cout << "        --ignoresslerrors    Ignore SSL errors "
                              "(dangerous, use with care!)\n";
-                std::cout << "    -v  --version         Show version "
+                std::cout << "    -v  --version            Show version "
                              "information and exit\n";
-                std::cout << "    -h  --help            Show this help and "
+                std::cout << "    -h  --help               Show this help and "
                              "exit\n";
                 std::cout << "\n";
 
@@ -114,6 +118,7 @@ int main(int argc, char *argv[])
             if (argument.startsWith("--version", Qt::CaseInsensitive)
              || argument.startsWith("-v", Qt::CaseInsensitive))
             {
+                // Version information already shown
                 return 0;
             }
 
@@ -155,7 +160,27 @@ int main(int argc, char *argv[])
                              "*** WARNING: Ignoring SSL errors. ***\n"
                              "***          This is insecure!    ***\n"
                              "*************************************\n";
-            }            
+            }
+
+            // Option to set link color (useful in GTK environments)
+            if (argument.startsWith("--linkcolor=", Qt::CaseInsensitive))
+            {
+                QString linkColorName = argument.split("=").last();
+                QColor linkColor = QColor(linkColorName);
+                if (linkColor.isValid())
+                {
+                    QPalette newPalette = dianaraApp.palette();
+                    newPalette.setColor(QPalette::Link, linkColor);
+                    dianaraApp.setPalette(newPalette);
+
+                    std::cout << "Forcing link color to: "
+                              << linkColorName.toStdString() << "\n";
+                }
+                else
+                {
+                    std::cout << "Invalid link color specified!\n";
+                }
+            }
         }
     }
 
@@ -203,7 +228,7 @@ int main(int argc, char *argv[])
         dianaraWindow.enableIgnoringSslErrors();
     }
 
-    dianaraWindow.toggleMainWindow();  // show()
+    dianaraWindow.toggleMainWindow(true);  // show(), firstTime=true
 
 
     return dianaraApp.exec();
