@@ -72,6 +72,7 @@
 #include "helpwidget.h"
 #include "groupsmanager.h"
 #include "globalobject.h"
+#include "userposts.h"
 
 
 class MainWindow : public QMainWindow
@@ -146,6 +147,8 @@ public slots:
     void scrollActivityTimelineToWidget(QWidget *widget);
     void scrollFavoritesTimelineToWidget(QWidget *widget);
 
+    void scrollToNewPosts();
+
     void notifyTimelineUpdate(PumpController::requestTypes timelineType,
                               int newPostCount, int highlightCount,
                               int deletedPostCount, int filteredPostCount,
@@ -175,6 +178,9 @@ public slots:
     void refreshAllTimestamps();
     void adjustTimelineSizes();
 
+    void showUserTimeline(QString userId, QString userName,
+                          QIcon userAvatar, QString userOutbox);
+
 
     void toggleSidePanel(bool shown);
     void toggleToolbar(bool shown);
@@ -191,9 +197,10 @@ public slots:
     void visitPumpGuide();
     void visitTips();
     void visitUserList();
+    void visitPumpStatus();
     void aboutDianara();
 
-    void toggleMainWindow();
+    void toggleMainWindow(bool firstTime=false);
 
     void showAuthError(QString title, QString message);
 
@@ -246,6 +253,7 @@ private:
     QAction *helpVisitPumpGuide;
     QAction *helpVisitPumpTips;
     QAction *helpVisitPumpUserList;
+    QAction *helpVisitPumpStatus;
     QAction *helpAbout;
     ////////////////////////////////////// End menus
 
@@ -261,6 +269,10 @@ private:
     QToolButton *statusStateButton;
     QToolButton *statusLogButton;
 
+    QPushButton *statusAccountButton; // Shown when no account is configured
+    bool statusAccountButtonUsed;
+    QProgressBar *initializationProgressBar;
+
 
     QSplitter *mainSplitter;
 
@@ -344,6 +356,7 @@ private:
     QTimer *postInitTimer;
     QTimer *favoritesReloadTimer;
     QTimer *userDidSomethingTimer;
+    QTimer *delayedScrollTimer;
 
     QString oldStatusBarMessage;
     QString previousStatusMessageFromTimeline;
