@@ -463,6 +463,28 @@ QString MiscHelpers::quotedText(QString author, QString content)
 }
 
 
+/*
+ * Limit length of a string to charLimit chars,
+ * removing characters from the middle
+ *
+ */
+QString MiscHelpers::elidedText(QString text, int charLimit)
+{
+    QString shortText = text;
+
+    if (text.length() > charLimit)
+    {
+        charLimit -= 5;
+
+        shortText = text.left(charLimit / 2);
+        shortText.append(" ... ");
+        shortText.append(text.right(charLimit / 2));
+    }
+
+    return shortText;
+}
+
+
 
 /*
  * Generate the first part of the HTML of a post
