@@ -30,6 +30,7 @@ PageSelector::PageSelector(QWidget *parent) : QWidget(parent)
     this->setWindowModality(Qt::ApplicationModal);
 
 
+    // Top
     this->messageLabel = new QLabel(tr("Page number:"),
                                     this);
 
@@ -41,20 +42,52 @@ PageSelector::PageSelector(QWidget *parent) : QWidget(parent)
 
     this->rangeLabel = new QLabel(this);
 
+
+    this->firstButton = new QPushButton(QIcon::fromTheme("go-first-view-page",
+                                                            QIcon(":/images/button-previous.png")),
+                                           tr("&First", "As in: first page"),
+                                           this);
+    connect(firstButton, SIGNAL(clicked()),
+            this, SLOT(setToFirstPage()));
+
+    this->lastButton = new QPushButton(QIcon::fromTheme("go-last-view-page",
+                                                            QIcon(":/images/button-next.png")),
+                                           tr("&Last", "As in: last page"),
+                                           this);
+    connect(lastButton, SIGNAL(clicked()),
+            this, SLOT(setToLastPage()));
+
+
+    // Middle
+    this->newerLabel = new QLabel("< " + tr("Newer",
+                                            "As in: newer pages"), this);
+
+    this->pageNumberSlider = new QSlider(Qt::Horizontal, this);
+    pageNumberSlider->setRange(1, 1);  // Initially
+    pageNumberSlider->setValue(1);
+    pageNumberSlider->setTickPosition(QSlider::TicksBelow);
+
+
+    // Make spinbox and slider keep in sync
+    connect(pageNumberSpinbox, SIGNAL(valueChanged(int)),
+            pageNumberSlider, SLOT(setValue(int)));
+    connect(pageNumberSlider, SIGNAL(valueChanged(int)),
+            pageNumberSpinbox, SLOT(setValue(int)));
+
+
+    this->olderLabel = new QLabel(tr("Older",
+                                     "As in: older pages") + " >", this);
+
+
+
+    // Bottom
     this->goButton = new QPushButton(QIcon::fromTheme("go-next-view-page",
                                                       QIcon(":/images/button-next.png")),
-                                     tr("&Go") + " >>",
+                                     "  " + tr("&Go") + " >>  ",
                                      this);
     connect(goButton, SIGNAL(clicked()),
             this, SLOT(goToPage()));
 
-    this->goToLastButton = new QPushButton(QIcon::fromTheme("go-last-view-page",
-                                                            QIcon(":/images/button-next.png")),
-                                           tr("Go to &last page"),
-                                           this);
-    connect(goToLastButton, SIGNAL(clicked()),
-            this, SLOT(goToLastPage()));
-
 
     this->closeButton = new QPushButton(QIcon::fromTheme("window-close",
                                                          QIcon(":/images/button-cancel.png")),
@@ -74,23 +107,37 @@ PageSelector::PageSelector(QWidget *parent) : QWidget(parent)
     // Layout
     this->topLayout = new QHBoxLayout();
     topLayout->addWidget(messageLabel);
+    topLayout->addSpacing(4);
     topLayout->addWidget(pageNumberSpinbox);
     topLayout->addSpacing(4);
     topLayout->addWidget(rangeLabel);
     topLayout->addSpacing(8);
-    topLayout->addWidget(goButton, 1);
+    topLayout->addStretch(1);
+    topLayout->addWidget(firstButton);
+    topLayout->addWidget(lastButton);
+
+
+    this->middleLayout = new QHBoxLayout();
+    middleLayout->addWidget(newerLabel);
+    middleLayout->addSpacing(4);
+    middleLayout->addWidget(pageNumberSlider);
+    middleLayout->addSpacing(4);
+    middleLayout->addWidget(olderLabel);
+
 
     this->bottomLayout = new QHBoxLayout();
-    bottomLayout->addWidget(goToLastButton);
-    bottomLayout->addSpacing(16);
+    bottomLayout->setAlignment(Qt::AlignRight);
+    bottomLayout->addWidget(goButton);
     bottomLayout->addWidget(closeButton);
 
 
     this->mainLayout = new QVBoxLayout();
     mainLayout->addLayout(topLayout);
-    mainLayout->addSpacing(22);
+    mainLayout->addSpacing(24);
     mainLayout->addStretch(1);
-    mainLayout->addSpacing(22);
+    mainLayout->addLayout(middleLayout);
+    mainLayout->addStretch(2);
+    mainLayout->addSpacing(32);
     mainLayout->addLayout(bottomLayout);
     this->setLayout(mainLayout);
 
@@ -113,7 +160,12 @@ void PageSelector::showForPage(int currentPage, int totalPageCount)
 {
     this->pageNumberSpinbox->setRange(1, totalPageCount);
     this->pageNumberSpinbox->setValue(currentPage);
-    this->rangeLabel->setText(QString("[ 1-%1 ]").arg(totalPageCount));
+
+    this->pageNumberSlider->setRange(1, totalPageCount);
+    // Value will get sync'ed from pageNumberSpinbox
+    this->pageNumberSlider->setTickInterval(totalPageCount / 4); // One tick every 1/4th
+
+    this->rangeLabel->setText(QString("[ 1 - %1 ]").arg(totalPageCount));
 
     this->show();
     this->pageNumberSpinbox->setFocus();
@@ -125,6 +177,18 @@ void PageSelector::showForPage(int currentPage, int totalPageCount)
 ////////////////////////////////////////////////////////////////////////////////
 
 
+void PageSelector::setToFirstPage()
+{
+    this->pageNumberSpinbox->setValue(this->pageNumberSpinbox->minimum());
+}
+
+
+void PageSelector::setToLastPage()
+{
+    this->pageNumberSpinbox->setValue(this->pageNumberSpinbox->maximum());
+}
+
+
 void PageSelector::goToPage()
 {
     emit pageJumpRequested(this->pageNumberSpinbox->value());
@@ -133,12 +197,6 @@ void PageSelector::goToPage()
 }
 
 
-void PageSelector::goToLastPage()
-{
-    emit pageJumpRequested(this->pageNumberSpinbox->maximum()); // FIXME
-
-    this->hide();
-}
 
 void PageSelector::onPageNumberEntered()
 {
