@@ -229,19 +229,26 @@ Post::Post(ASActivity *activity,
                 this, SLOT(showHighlightedUrl(QString)));
 
 
-        QString shareTooltip = "<img align=\"left\" src=\""
+        QString shareTooltip = "<table cellpadding=8>"
+                               "<tr>"
+                               "<td>"
+                               "<img align=\"left\" src=\""
                                + sharedByAvatar
-                               + "\" width=\"96\" />";
-        shareTooltip.append("&nbsp;&nbsp;<b>"
+                               + "\" width=\"96\" />"
+                                 "</td>";
+        shareTooltip.append("<td><b>"
                             + sharedByName
                             + "</b><br>");
-        shareTooltip.append("&nbsp;&nbsp;<i>"
+        shareTooltip.append("<i>"
                             + this->postSharedById
-                            + "</i>");
+                            + "</i>"
+                              "</td>"
+                              "</tr>"
+                              "</table>");
 
 
         QString exactShareTime = Timestamp::localTimeDate(postShareTime);
-        shareTooltip.append("<br><hr><br><p>"
+        shareTooltip.append("<hr>"
                             + tr("Shared on %1").arg(exactShareTime));
         if (!this->postGeneratorString.isEmpty())
         {
@@ -251,7 +258,7 @@ Post::Post(ASActivity *activity,
                                   .arg(this->postGeneratorString));
             this->postGeneratorString.clear(); // So it's not used in the post timestamp tooltip!
         }
-        shareTooltip.append("</p>");
+
         postIsSharedLabel->setToolTip(shareTooltip);
     }
 
@@ -354,9 +361,9 @@ Post::Post(ASActivity *activity,
     }
 
     // Author name
-    postAuthorNameLabel = new QLabel(postAuthorName);
+    postAuthorNameLabel = new QLabel(postAuthorName, this);
     postAuthorNameLabel->setTextFormat(Qt::PlainText);
-    postAuthorNameLabel->setWordWrap(true);
+    postAuthorNameLabel->setWordWrap(true /* make optional */);
     postAuthorNameLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     postAuthorNameLabel->setFont(authorFont);
     postAuthorNameLabel->setToolTip(authorPerson->getTooltipInfo());
@@ -1722,6 +1729,8 @@ void Post::commentOnPost()
         // Selected text has literal < and >, so convert to HTML entities
         selectedText.replace("<", "&lt;");
         selectedText.replace(">", "&gt;");
+        selectedText.prepend("[...] ");
+        selectedText.append(" [...]");
         initialText = MiscHelpers::quotedText(this->postAuthorName,
                                               selectedText);
     }
