@@ -45,8 +45,14 @@
 /// For JSON parsing
 #include <QVariant>
 #include <QVariantMap>
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
+// Qt 4
 #include <qjson/parser.h>
 #include <qjson/serializer.h>
+#else
+// Qt 5
+#include <QJsonDocument>
+#endif
 
 // For OAuth authentication
 #include <QtOAuth>
@@ -70,6 +76,7 @@ public:
 
         UserProfileRequest,
         UpdateProfileRequest,
+        UpdateEmailRequest,
 
         FollowingListRequest,
         FollowersListRequest,
@@ -89,6 +96,7 @@ public:
         DirectTimelineRequest,
         ActivityTimelineRequest,
         FavoritesTimelineRequest,
+        UserTimelineRequest,
 
         PostLikesRequest,
         PostCommentsRequest,
@@ -149,6 +157,7 @@ public:
     void getUserProfile(QString userId);
     void updateUserProfile(QString avatarUrl, QString fullName,
                            QString hometown, QString bio);
+    void updateUserEmail(QString newEmail, QString password);
 
     void enqueueAvatarForDownload(QString url);
     void enqueueImageForDownload(QString url);
@@ -211,6 +220,9 @@ public:
     void setIgnoreSslErrors(bool state);
     void setIgnoreSslInImages(bool state);
 
+    void setSilentFollows(bool state);
+    void setSilentLists(bool state);
+
     void updatePostsEverSeen(QVariantMap postMap);
     QVariantMap getPostsEverSeen();
 
@@ -219,6 +231,7 @@ signals:
     void openingAuthorizeURL(QUrl url);
     void authorizationFailed(QString errorTitle, QString errorMessage);
     void authorizationStatusChanged(bool authorized);
+    void initializationStepChanged(int step);
     void initializationCompleted();
 
     void profileReceived(QString avatarURL, QString fullName,
@@ -236,18 +249,17 @@ signals:
     void personRemovedFromList(QString id);
 
 
-    void mainTimelineReceived(QVariantList postList, int postsPerPage,
-                              QString previousLink, QString nextLink,
-                              int totalItems);
-    void directTimelineReceived(QVariantList postList, int postsPerPage,
-                                QString previousLink, QString nextLink,
-                                int totalItems);
-    void activityTimelineReceived(QVariantList postList, int postsPerPage,
-                                  QString previousLink, QString nextLink,
-                                  int totalItems);
-    void favoritesTimelineReceived(QVariantList postList, int postsPerPage,
-                                   QString previousLink, QString nextLink,
-                                   int totalItems);
+    void mainTimelineReceived(QVariantList postList, QString previousLink,
+                              QString nextLink, int totalItems);
+    void directTimelineReceived(QVariantList postList, QString previousLink,
+                                QString nextLink, int totalItems);
+    void activityTimelineReceived(QVariantList postList, QString previousLink,
+                                  QString nextLink, int totalItems);
+    void favoritesTimelineReceived(QVariantList postList, QString previousLink,
+                                   QString nextLink, int totalItems);
+    void userTimelineReceived(QVariantList postList, QString previousLink,
+                              QString nextLink, int totalItems,
+                              QString url);
 
     void likesReceived(QVariantList likesList, QString originatingPostURL);
     void commentsReceived(QVariantList commentsList, QString originatingPostURL);
@@ -389,6 +401,9 @@ private:
 
     bool ignoreSslErrors;
     bool ignoreSslInImages;
+
+    bool silentFollows;
+    bool silentListsHandling;
 };
 
 #endif // PUMPCONTROLLER_H
