@@ -66,7 +66,7 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
     case PumpController::MainTimelineRequest:
         demoObjectData.insert("displayName", tr("Welcome to Dianara"));
         demoObjectData.insert("content",
-                              tr("Dianara is a <b>pump.io</b> client.")
+                              tr("Dianara is a <b>Pump.io</b> client.")
                               + "<br>"
 
                               + tr("If you don't have a Pump account yet, you can get one "
@@ -165,8 +165,7 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
     this->wasOnFirstPage = true;
     this->pendingToReceiveNextTime = 0;
 
-    this->postsPerPage = 1;    // 1 at first, so initial page number calculation makes sense
-
+    this->syncPostsPerPage();
 
 
     // Separator frame, to mark where new posts from the last batch end
@@ -177,6 +176,15 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
     separatorFrame->hide();
 
 
+    // Info label, shown when there are no posts, or to indicate loading and such
+    infoLabel = new QLabel(this);
+    infoLabel->setAlignment(Qt::AlignCenter);
+    infoLabel->setWordWrap(true);
+    infoLabel->setSizePolicy(QSizePolicy::MinimumExpanding,
+                             QSizePolicy::Expanding);
+    infoLabel->hide();
+
+
     getNewPendingButton = new QPushButton(QIcon::fromTheme("view-refresh",
                                                            QIcon(":/images/menu-refresh.png")),
                                           "*get more pending messages*",
@@ -187,6 +195,16 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
     getNewPendingButton->hide();
 
 
+    // This will hold the posts and be hidden or disabled when needed
+    postsWidget = new QWidget(this);
+    postsWidget->setContentsMargins(0, 0, 0, 0);
+    if (this->timelineType == PumpController::UserTimelineRequest)
+    {
+        postsWidget->hide(); // Will be shown when ready
+        // Hiding it now ensures the infoLabel messages appear well centered
+    }
+
+
     firstPageButton = new QPushButton(QIcon::fromTheme("go-first",
                                                        QIcon(":/images/button-previous.png")),
                                       tr("Newest"),
@@ -228,6 +246,7 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
     ///// Layout
     postsLayout = new QVBoxLayout();
     postsLayout->setContentsMargins(0, 0, 0, 0);
+    this->postsWidget->setLayout(postsLayout);
     // Setting alignment of this layout to AlignTop caused all posts to be
     // compressed at the top when there were a lot of them; removed
 
@@ -246,7 +265,8 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
     mainLayout = new QVBoxLayout();
     mainLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->addWidget(getNewPendingButton);
-    mainLayout->addLayout(postsLayout, 1);
+    mainLayout->addWidget(infoLabel,   2);
+    mainLayout->addWidget(postsWidget, 1);
     mainLayout->addStretch(0); // Ensure buttons are always at the bottom
     mainLayout->addSpacing(2);              // 2 pixel separation
     mainLayout->addLayout(bottomLayout, 0);
@@ -311,15 +331,25 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
 
 
     // Add the default "demo" post
-    ASActivity *demoActivity = new ASActivity(demoPostData, this);
-    Post *demoPost = new Post(demoActivity,
-                              false, // Not highlighted
-                              false, // Not standalone
-                              pController,
-                              globalObj,
-                              this);
-    postsInTimeline.append(demoPost);
-    postsLayout->addWidget(demoPost);
+    if (timelineType != PumpController::UserTimelineRequest)
+    {
+        ASActivity *demoActivity = new ASActivity(demoPostData, this);
+        Post *demoPost = new Post(demoActivity,
+                                  false, // Not highlighted
+                                  false, // Not standalone
+                                  pController,
+                                  globalObj,
+                                  this);
+        postsInTimeline.append(demoPost);
+        postsLayout->addWidget(demoPost);
+    }
+    else
+    {
+        this->infoLabel->setText("<big><b>"
+                                 + tr("Requesting...")
+                                 + "</b></big>");
+        this->infoLabel->show();
+    }
 
 
 
@@ -381,11 +411,19 @@ TimeLine::~TimeLine()
 
 
 
+
+void TimeLine::setCustomUrl(QString url)
+{
+    this->customUrl = url;
+}
+
+
+
 /*
  * Remove all widgets (Post *) from the timeline
  *
  */
-void TimeLine::clearTimeLineContents()
+void TimeLine::clearTimeLineContents(bool showMessage)
 {
     foreach (Post *oldPost, postsInTimeline)
     {
@@ -400,6 +438,12 @@ void TimeLine::clearTimeLineContents()
     this->postsLayout->removeWidget(separatorFrame);
     separatorFrame->hide();
 
+    if (showMessage)
+    {
+        this->infoLabel->setText("<big><b>" + tr("Loading...") + "</b></big>");
+        this->infoLabel->show();
+    }
+
     qApp->processEvents(); // So GUI gets updated
 }
 
@@ -491,7 +535,15 @@ int TimeLine::getTotalPages()
         this->postsPerPage = 1;
     }
 
-    return qCeil(this->fullTimelinePostCount / (float)this->postsPerPage);
+    int totalPages = qCeil(this->fullTimelinePostCount / (float)this->postsPerPage);
+
+    return qMax(totalPages, 1); // 1 is the minimum
+}
+
+
+int TimeLine::getTotalPosts()
+{
+    return this->fullTimelinePostCount;
 }
 
 
@@ -525,13 +577,22 @@ void TimeLine::updateCurrentPageNumber()
                                              "jump to a specific page")
                                         + "</i></b>");
 
-    if (currentPage == totalPages)
+    this->previousPageButton->setDisabled(currentPage == 1); // Disabled on 1st page
+    this->nextPageButton->setDisabled(currentPage == totalPages); // Disabled on last page
+}
+
+
+
+void TimeLine::syncPostsPerPage()
+{
+    if (this->timelineType == PumpController::MainTimelineRequest
+     || this->timelineType == PumpController::UserTimelineRequest)
     {
-        this->nextPageButton->setDisabled(true);
+        this->postsPerPage = this->globalObj->getPostsPerPageMain();
     }
     else
     {
-        this->nextPageButton->setEnabled(true);
+        this->postsPerPage = this->globalObj->getPostsPerPageOther();
     }
 }
 
@@ -553,10 +614,15 @@ void TimeLine::resizePosts(QList<Post *> postsToResize, bool resizeAll)
     {
         post->resetResizesCount();
 
-        // Force a Post() resizeEvent, which will call
-        // setPostContents() and setPostHeight()
+        // Call setPostContents() and setPostHeight()
+
+        // New method, disabled for 1.3.1; has some drawbacks
+        //post->onResizeOrShow();
+
+        /* -- Old method, forcing a resize */
         post->resize(post->width() - 1,
                      post->height() - 1);
+        /* re-enabled for 1.3.1 */
     }
 }
 
@@ -586,6 +652,7 @@ void TimeLine::updateFuzzyTimestamps()
     }
 }
 
+
 bool TimeLine::commentingOnAnyPost()
 {
     foreach (Post *post, postsInTimeline)
@@ -619,6 +686,12 @@ QList<Post *> TimeLine::getPostsInTimeline()
 }
 
 
+QFrame *TimeLine::getSeparatorFrame()
+{
+    return this->separatorFrame;
+}
+
+
 
 /*****************************************************************************/
 /*****************************************************************************/
@@ -627,18 +700,23 @@ QList<Post *> TimeLine::getPostsInTimeline()
 /*****************************************************************************/
 
 
-void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
-                                   QString previousLink, QString nextLink,
-                                   int totalItems)
+void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
+                                   QString nextLink, int totalItems)
 {
     qDebug() << "TimeLine::setTimeLineContents()";
     int postListSize = postList.size();
 
+    // Disable to avoid clicks to posts (which would mark them as read)
+    if (postListSize > 0)   // until fully updated
+    {
+        this->setDisabled(true);
+    }
+
     // Remove all previous posts in timeline, when switching pages
     if (firstLoad || !wasOnFirstPage || favoritesTimeline || timelineOffset > 0)
     {
-        // Hide the widget while it reloads; helps performance a lot
-        this->hide();
+        // Hide the posts while TL reloads; helps performance a lot
+        this->postsWidget->hide();
 
         qDebug() << "Removing previous posts from timeline";
         this->clearTimeLineContents();
@@ -660,17 +738,9 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
             this->previousPageLink = previousLink;
             // Just the previousLink; don't store nextLink, keep the old one
         }
-
-        if (postListSize > 0)
-        {
-            // Disable to avoid clicks to posts (which would mark them as read)
-            this->setDisabled(true); // until fully updated
-        }
     }
 
 
-    this->postsPerPage = postsPerPage;
-
     int totalPostDifference = totalItems - this->fullTimelinePostCount;
     this->fullTimelinePostCount = totalItems;
 
@@ -685,7 +755,7 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
             // The difference in pending posts is in the older pages, so doesn't count
             this->pendingToReceiveNextTime = 0;
 
-            // FIXME 1.3.1: On first load, should display the "pending" number
+            // FIXME 1.3.x: On first load, should display the "pending" number
             // at the bottom or at the "older" button
         }
         else
@@ -805,7 +875,8 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
                         && !postIsDuplicated
                         && activity->author()->getId() != pController->currentUserId()
                         && activity->object()->author()->getId() != pController->currentUserId()
-                        && !favoritesTimeline)
+                        && !favoritesTimeline
+                        && this->timelineType != PumpController::UserTimelineRequest)
                     {
                         ++newPostCount;
 
@@ -951,8 +1022,22 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
                                      fullTimelinePostCount);
     }
 
-    // Show and enable timeline again, since everything is added and drawn
-    this->show();
+
+    if (postsInTimeline.length() == 0)
+    {
+        this->infoLabel->setText("<big><b>"
+                                 + tr("There are no posts")
+                                 + "</b></big>");
+        this->infoLabel->show();
+        this->postsWidget->hide();
+    }
+    else
+    {
+        this->infoLabel->hide();
+        this->postsWidget->show(); // Show posts again
+    }
+
+    // Enable timeline again, since everything is added and drawn
     this->setEnabled(true);
 
     qDebug() << "setTimeLineContents() /END";
@@ -1142,6 +1227,8 @@ void TimeLine::goToFirstPage()
         return;
     }
 
+    this->syncPostsPerPage();
+
     this->gettingNew = true;
 
     if (timelineOffset == 0) // On page 1
@@ -1154,6 +1241,8 @@ void TimeLine::goToFirstPage()
 
         this->previousPageLink.clear();  // Full reload of newest stuff
         this->timelineOffset = 0;
+
+        this->setDisabled(true); // Disable soon, to avoid wrong clicks
     }
 
     /*
@@ -1177,8 +1266,12 @@ void TimeLine::goToPreviousPage()
         return;
     }
 
+    this->syncPostsPerPage();
+
     this->gettingNew = false;
 
+    this->setDisabled(true); // Disable soon, to avoid wrong clicks
+
     this->timelineOffset -= this->postsPerPage;
     if (timelineOffset < 0)
     {
@@ -1211,8 +1304,12 @@ void TimeLine::goToNextPage()
         return;
     }
 
+    this->syncPostsPerPage();
+
     this->gettingNew = false;
 
+    this->setDisabled(true); // Disable soon, to avoid wrong clicks
+
     this->timelineOffset += this->postsPerPage;
 
     if (!favoritesTimeline) // Not favorites, use NextLink
@@ -1240,14 +1337,36 @@ void TimeLine::goToSpecificPage(int pageNumber)
         return;
     }
 
+    this->syncPostsPerPage();
+
     this->gettingNew = false;
 
+    this->setDisabled(true); // Disable soon, to avoid wrong clicks
+
     this->timelineOffset = (pageNumber - 1) * this->postsPerPage;
 
+    /* Workaround for Pump.io core bug:
+     *
+     *    Ensure that timelineOffset is NOT greater
+     *    than fullTimelinePostCount - postsPerPage
+     *
+     * Otherwise, when requesting the last page, the server might return
+     * ALL posts, even beyond API limits, instead of the last (oldest) few
+     * posts.
+     *
+     * https://github.com/e14n/pump.io/issues/1087
+     *
+     */
+    if (this->timelineType == PumpController::UserTimelineRequest)
+    {
+        int maxTimelineOffset = this->fullTimelinePostCount - this->postsPerPage;
+        this->timelineOffset = qMin(this->timelineOffset, maxTimelineOffset);
+    }
+
     pController->getFeed(this->timelineType,
                          this->postsPerPage,
-                         "", // No prev/next link, use offset instead
-                         this->timelineOffset);
+                         this->customUrl, // No prev/next links, use possible customUrl or empty
+                         this->timelineOffset); // And use offset instead
 }
 
 
