@@ -52,13 +52,17 @@ public:
              QWidget *parent = 0);
     ~TimeLine();
 
-    void clearTimeLineContents();
+    void setCustomUrl(QString url);
+
+    void clearTimeLineContents(bool showMessage=true);
     void removeOldPosts(int minimumToKeep);
     void insertSeparator(int position);
 
     int getCurrentPage();
     int getTotalPages();
+    int getTotalPosts();
     void updateCurrentPageNumber();
+    void syncPostsPerPage();
 
     void resizePosts(QList<Post *> postsToResize, bool resizeAll=false);
 
@@ -71,6 +75,8 @@ public:
 
     QList<Post *> getPostsInTimeline();
 
+    QFrame *getSeparatorFrame();
+
 
 signals:
     void scrollTo(QAbstractSlider::SliderAction sliderAction);
@@ -90,9 +96,8 @@ signals:
 
 
 public slots:
-    void setTimeLineContents(QVariantList postList, int postsPerPage,
-                             QString previousLink, QString nextLink,
-                             int totalItems);
+    void setTimeLineContents(QVariantList postList, QString previousLink,
+                             QString nextLink, int totalItems);
 
     void updatePostsFromMinorFeed(ASObject *object);
     void addLikesFromMinorFeed(QString objectId, QString objectType,
@@ -126,6 +131,7 @@ public slots:
 
     void updateAvatarFollowStates();
 
+
 protected:
 
 
@@ -138,16 +144,20 @@ private:
     GlobalObject *globalObj;
     FilterChecker *fChecker;
 
+
+    QPushButton *getNewPendingButton;
+    QLabel *infoLabel;
+
+    QWidget *postsWidget;
+    QFrame *separatorFrame;
+
     QPushButton *firstPageButton;
     QPushButton *currentPageButton;
     QPushButton *previousPageButton;
     QPushButton *nextPageButton;
 
-    QPushButton *getNewPendingButton;
-
-    QFrame *separatorFrame;
-
 
+    QString customUrl;
     QString previousPageLink;
     QString nextPageLink;
     int fullTimelinePostCount;
